 /*
 * FILE --- main_veh_sim_ex.cc 
 *
 * PURPOSE --- To rpovide an example use of the class for 4'th
 * order Runge-Kutta simulation, RK4_SIM.
 * Implements the man function of a class for performing a simulation of
 * a simple vehicle with point mass dynamics.
 *
 */

// Include Files
//#include <stdlib.h>
//#include <math.h>
#include <stdio.h>   // fprintf
#include "veh_sim_ex.hh"

void main(void) 
{
  
  double Ts = 0.01;             // Sampling time
  double y[3] = {0.0,0.0,0.0};  // Initial conditions    
  double t0 = 0.0;              // Initial time 
  double tmax = 5;              // Total Simulation period
  
  // # of simulation steps to be performed by the RK4 algorith
  // in one sampling interval
  int sim_per_cycle = 5;  

  // Create the vehicle object
  VEH_SIM my_vehicle(Ts,sim_per_cycle,t0,(double *)y);

  FILE *fp;  // To save data

  if (!(fp = fopen("output.dat","w"))) {
    printf("Can't open file.\n");
    exit(1);
  }

  /* Simulate For tmax seconds. */
  while(my_vehicle.current_time < tmax) 
    {
      // Simulate one sampling interval
      my_vehicle.simulate();

      // Save the current time and state to a file
      fprintf(fp,"%f %f %f %f %f %f %f\n", my_vehicle.current_time,
	      my_vehicle.plant_state[0], my_vehicle.plant_state[1],
	      my_vehicle.plant_state[2], my_vehicle.ctrl_input[0],
	      my_vehicle.ctrl_input[1], my_vehicle.ctrl_input[2]);
    }

  fclose(fp);
}
